pynrc.simul.ngNRC
=================

.. automodule:: pynrc.simul.ngNRC

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      add_col_noise
      add_cosmic_rays
      add_xtalk
      apply_flat
      create_level1b_FITS
      fft_noise
      gen_col_noise
      gen_dark_ramp
      gen_ramp_biases
      gen_wfe_drift
      make_gaia_source_table
      make_ramp_poisson
      make_simbad_source_table
      pink_noise
      save_slope_image
      sim_dark_ramp
      sim_image_ramp
      sim_noise_data
      simulate_detector_ramp
      slope_to_fitswriter
      slope_to_level1b
      sources_to_level1b
      sources_to_slope
      xtalk_image
   
   

   
   
   

   
   
   



